@@ -40,16 +40,4 @@ class AuthResponseHandlerTemplate(AbstractAuthResponseHandlerTemplate):
     def get_token(self): ...
 
 
-class NapoleonServiceAuthHandler(AuthResponseHandlerTemplate):
 
-    def _get_token(self):
-        return self._response["access_token"]
-
-    def _get_token_type(self):
-        return str(self._response["token_type"]).capitalize()
-
-    def get_token(self):
-        _token = Token()
-        _token.value = self._get_token()
-        _token.type = self._get_token_type()
-        return _token
