@@ -105,6 +105,94 @@ class NaPoleonBinanceFutureBot(object):
         result_df = result_df[result_df['date'] == request_date]
         return result_df
 
+    def get_futures_positions_margin_change_history(self, assets, start_time, end_time):
+        transfer_df = None
+        for asset in assets:
+            if transfer_df is None:
+                transfer_df = self.get_futures_positiion_margin_change_history(asset, start_time, end_time)
+            else:
+                add_transfer_df = self.get_futures_positiion_margin_change_history(asset, start_time, end_time)
+                if add_transfer_df is not None:
+                    transfer_df = pd.concat([transfer_df, add_transfer_df])
+        if transfer_df is not None:
+            return transfer_df[['date','asset','amount']]
+        return transfer_df
+
+    def get_futures_positiion_margin_change_history(self, asset, start_time, end_time):
+
+        startTime = int(start_time.timestamp() * 1000)
+        endTime = int(end_time.timestamp() * 1000)
+
+        BASE_URL = 'https://api.binance.com'
+        PATH = '/fapi/v1/positionMargin/history'
+
+
+        headers = {
+            'X-MBX-APIKEY': self.apiKey
+        }
+        timestamp = int(time.time() * 1000)
+
+        params = {
+            'symbol': asset,
+            'recvWindow': 60000,
+            'timestamp': timestamp,
+            'startTime': startTime,
+            'endTime': endTime,
+            # 'limit': 500,
+            # 'type':1
+        }
+        query_string = urllib.parse.urlencode(params)
+        params['signature'] = hmac.new(self.secret.encode('utf-8'), query_string.encode('utf-8'),
+                                       hashlib.sha256).hexdigest()
+        url = urljoin(BASE_URL, PATH)
+        print(url)
+        r = requests.get(url, headers=headers, params=params)
+        dataSet = r.json()
+        if dataSet['total']>0:
+            transfers = dataSet['rows']
+
+            transfer_df = pd.DataFrame(transfers)
+
+            transfer_df['date'] = pd.to_datetime(transfer_df['timestamp'], unit='ms')
+
+            return transfer_df
+        else :
+            return None
+
+
+    def get_future_position_risk(self):
+
+
+        BASE_URL = 'https://api.binance.com'
+        PATH = '/fapi/v2/positionRisk'
+
+
+        headers = {
+            'X-MBX-APIKEY': self.apiKey
+        }
+        timestamp = int(time.time() * 1000)
+
+        params = {
+            'recvWindow': 60000,
+            'timestamp': timestamp,
+        }
+        query_string = urllib.parse.urlencode(params)
+        params['signature'] = hmac.new(self.secret.encode('utf-8'), query_string.encode('utf-8'),
+                                       hashlib.sha256).hexdigest()
+        url = urljoin(BASE_URL, PATH)
+        print(url)
+        r = requests.get(url, headers=headers, params=params)
+        dataSet = r.json()
+        if dataSet['total']>0:
+            transfers = dataSet['rows']
+
+            transfer_df = pd.DataFrame(transfers)
+
+            transfer_df['date'] = pd.to_datetime(transfer_df['timestamp'], unit='ms')
+
+            return transfer_df
+        else :
+            return None
 
     def get_futures_transfer_history(self, assets, start_time, end_time):
         transfer_df = None
