@@ -37,7 +37,7 @@ def pairs_trading_simple_correlation(pair_df = None, correlation_threshold = 0.2
     return None
 
 
-def pair_trading_shifted_correlation(pair_df = None, correlation_range = 100, suffixes=('_btc', '_eth'), **kwargs):
+def pair_trading_shifted_correlation(pair_df = None, correlation_range = 100, variant = 'a', suffixes=('_btc', '_eth'), **kwargs):
     len_histo = len(pair_df)
     assert len_histo > correlation_range
     return_pair_df = cointegration_utilities.add_returns(pair_df, suffixes=suffixes)
@@ -47,10 +47,15 @@ def pair_trading_shifted_correlation(pair_df = None, correlation_range = 100, su
         shifted_df['return' + suffixes[1]] = return_pair_df['return'+suffixes[1]].shift(shift)
         correlation_dico[shift] = shifted_df[['return'+suffixes[0], 'return'+suffixes[1]]].corr().values[0][1]
     lag = max(correlation_dico, key=correlation_dico.get)
-    signal = return_pair_df['return'+suffixes[1]].values[-lag]
-    return -np.sign(signal), np.sign(signal)
+    if variant == 'a':
+        signal = return_pair_df['return' + suffixes[1]].values[-lag]
+        return -np.sign(signal), np.sign(signal)
 
-def pair_trading_shifted_correlation_with_cointegration(pair_df = None, correlation_range = 100, risk = 10, alpha = 0.05, suffixes=('_btc', '_eth'), **kwargs):
+    elif variant == 'b':
+        signal = np.mean(return_pair_df['return' + suffixes[1]].values[-lag:])
+        return np.sign(signal), -np.sign(signal)
+
+def pair_trading_shifted_correlation_with_cointegration(pair_df = None, correlation_range = 100, risk = 10, alpha = 0.05, variant = 'a', suffixes=('_btc', '_eth'), **kwargs):
     len_histo = len(pair_df)
     assert len_histo > correlation_range
     log_returns_df = cointegration_utilities.add_log_returns(pair_df, suffixes=suffixes)
@@ -65,8 +70,14 @@ def pair_trading_shifted_correlation_with_cointegration(pair_df = None, correlat
             shifted_df['return' + suffixes[1]] = return_pair_df['return'+suffixes[1]].shift(shift)
             correlation_dico[shift] = shifted_df[['return'+suffixes[0], 'return'+suffixes[1]]].corr().values[0][1]
         lag = max(correlation_dico, key=correlation_dico.get)
-        signal = return_pair_df['return'+suffixes[1]].values[-lag]
-        return -np.sign(signal), np.sign(signal)
+
+        if variant == 'a':
+            signal = return_pair_df['return'+suffixes[1]].values[-lag]
+            return -np.sign(signal), np.sign(signal)
+
+        elif variant == 'b':
+            signal = np.mean(return_pair_df['return'+suffixes[1]].values[-lag:])
+            return np.sign(signal), -np.sign(signal)
 
     else:
         return np.nan,np.nan
