@@ -109,6 +109,12 @@ def binance_get_futures_transfer_histo(api, p, start_time, end_time):
     bot = binance_bot.NaPoleonBinanceFutureBot(api, p)
     return bot.get_futures_transfer_history(['USDT', 'BNB'], start_time, end_time)
 
+def binance_get_position_history(api, p, start_time, end_time):
+    bot = binance_bot.NaPoleonBinanceFutureBot(api, p)
+    return bot.get_futures_positions_margin_change_history(['ETH','BTC'], start_time, end_time)
+
+
+
 #https://binance-docs.github.io/apidocs/spot/en/#wallet-endpoints
 def binance_get(api, p, type_, start_time, end_time = None, symbol = None, aggreg = None):
   '''
@@ -414,7 +420,7 @@ def numba_compute_fees(arr, d):
 
 
 
-def fetch_all_necessary_data(public_key = None, private_key= None, start_time= None, end_time= None, save_to_dropbox = False, dropbox_token = None, local_root_directory = './'):
+def fetch_all_necessary_data(public_key = None, private_key= None, start_time= None, end_time= None, save_to_dropbox = False, dropbox_token = None, local_root_directory = './', trade_only_granularity = True):
     dbx = dropbox_file_saver.NaPoleonDropboxConnector(drop_token=dropbox_token, dropbox_backup=True)
 
     start_time_stub = start_time.strftime('%d_%b_%Y')
@@ -696,44 +702,78 @@ def fetch_all_necessary_data(public_key = None, private_key= None, start_time= N
 
     td['date'] = td.index
 
-    wh = wh.drop(columns=['fut_transfer_usdt_amount'])
-    td = pd.merge(td, wh, how='left', left_on='date', right_on='date')
-    if fut_transfers is not None:
-        td['bench'] = 1.
+    if trade_only_granularity:
+        wh = pd.merge(wh, td, how='left', left_on='date', right_on='date')
+        wh['amount_traded_usd_eth'] = wh.traded_eth * wh.avg_eth_price
+        wh['amount_traded_usd_btc'] = wh.traded_xbt * wh.avg_btc_price
 
-        fut_transfers_old = pd.merge(fut_transfers_old, td[['date', 'bench']], how='outer', left_on='date', right_on='date')
-        fut_transfers_old = fut_transfers_old.sort_values(by='date')
-        fut_transfers_old['fut_transfer_usdt_amount'] = fut_transfers_old['fut_transfer_usdt_amount'].shift()
-        fut_transfers_old = fut_transfers_old.dropna()
+        x = wh[['traded_eth', 'avg_eth_price', 'amount_traded_usd_eth', 'sens_trade_eth', 'open_eth_cc', 'open_eth_bnc',
+                'traded_xbt', 'avg_btc_price', 'amount_traded_usd_btc', 'sens_trade_xbt', 'open_btc_cc', 'open_btc_bnc',
+                'valuation', 'fut_transfer_usdt_amount', 'wallet_balance',
+                'trading_fees_eth_usd', 'funding_fees_eth_usd', 'slippage_eth_price_cc', 'slippage_eth_cash_cc',
+                'slippage_eth_price_bnc', 'slippage_eth_cash_bnc',
+                'trading_fees_xbt_usd', 'funding_fees_xbt_usd', 'slippage_btc_price_cc', 'slippage_btc_cash_cc',
+                'slippage_btc_price_bnc', 'slippage_btc_cash_bnc']]
 
-        td = pd.merge(td, fut_transfers_old, how='left', left_on='date', right_on='date')
+        x.index = wh.date
+        x = x.rename_axis('timestamp')
+        x.columns = ['quantity_traded_eth', 'avg_traded_price_eth', 'amount_traded_usd_eth', 'n_trades_eth',
+                     'open_eth_cc', 'open_eth_exchange',
+                     'quantity_traded_btc', 'avg_traded_price_btc', 'amount_traded_usd_btc', 'n_trades_btc',
+                     'open_btc_cc', 'open_btc_exchange',
+                     'wallet_amount_usd', 'transfers_usd', 'wallet_binance_balance',
+                     'trading_fees_usd_eth', 'funding_fees_usd_eth', 'slippage_eth_price_cc', 'slippage_eth_cash_cc',
+                     'slippage_eth_price_bnc', 'slippage_eth_cash_bnc',
+                     'trading_fees_usd_btc', 'funding_fees_usd_btc', 'slippage_btc_price_cc', 'slippage_btc_cash_cc',
+                     'slippage_btc_price_bnc', 'slippage_btc_cash_bnc']
+
+        x = x.fillna(0).round(decimals=5)
+
+        full_path = local_root_directory + report_pkl_file_name
+        x.to_pickle(full_path)
+        print(f'uploading to dropbox {full_path}')
+        dbx.upload(fullname=full_path, folder='', subfolder='', name=report_pkl_file_name, overwrite=True)
+        os.remove(full_path)
     else:
-        td['fut_transfer_usdt_amount'] = 0.
+        wh = wh.drop(columns=['fut_transfer_usdt_amount'])
+        td = pd.merge(td, wh, how='left', left_on='date', right_on='date')
+        if fut_transfers is not None:
+            td['bench'] = 1.
+
+            fut_transfers_old = pd.merge(fut_transfers_old, td[['date', 'bench']], how='outer', left_on='date', right_on='date')
+            fut_transfers_old = fut_transfers_old.sort_values(by='date')
+            fut_transfers_old['fut_transfer_usdt_amount'] = fut_transfers_old['fut_transfer_usdt_amount'].shift()
+            fut_transfers_old = fut_transfers_old.dropna()
+
+            td = pd.merge(td, fut_transfers_old, how='left', left_on='date', right_on='date')
+        else:
+            td['fut_transfer_usdt_amount'] = 0.
 
 
-    td['amount_traded_usd_eth'] = td.traded_eth * td.avg_eth_price
-    td['amount_traded_usd_btc'] = td.traded_xbt * td.avg_btc_price
+        td['amount_traded_usd_eth'] = td.traded_eth * td.avg_eth_price
+        td['amount_traded_usd_btc'] = td.traded_xbt * td.avg_btc_price
 
-    x = td[['traded_eth', 'avg_eth_price', 'amount_traded_usd_eth', 'sens_trade_eth', 'open_eth_cc', 'open_eth_bnc',
-            'traded_xbt', 'avg_btc_price', 'amount_traded_usd_btc', 'sens_trade_xbt', 'open_btc_cc', 'open_btc_bnc',
-            'valuation', 'fut_transfer_usdt_amount','wallet_balance',
-            'trading_fees_eth_usd', 'funding_fees_eth_usd', 'slippage_eth_price_cc', 'slippage_eth_cash_cc','slippage_eth_price_bnc', 'slippage_eth_cash_bnc',
-            'trading_fees_xbt_usd', 'funding_fees_xbt_usd', 'slippage_btc_price_cc', 'slippage_btc_cash_cc','slippage_btc_price_bnc', 'slippage_btc_cash_bnc' ]]
+        x = td[['traded_eth', 'avg_eth_price', 'amount_traded_usd_eth', 'sens_trade_eth', 'open_eth_cc', 'open_eth_bnc',
+                'traded_xbt', 'avg_btc_price', 'amount_traded_usd_btc', 'sens_trade_xbt', 'open_btc_cc', 'open_btc_bnc',
+                'valuation', 'fut_transfer_usdt_amount','wallet_balance',
+                'trading_fees_eth_usd', 'funding_fees_eth_usd', 'slippage_eth_price_cc', 'slippage_eth_cash_cc','slippage_eth_price_bnc', 'slippage_eth_cash_bnc',
+                'trading_fees_xbt_usd', 'funding_fees_xbt_usd', 'slippage_btc_price_cc', 'slippage_btc_cash_cc','slippage_btc_price_bnc', 'slippage_btc_cash_bnc' ]]
 
-    x = x.rename_axis('timestamp')
-    x.columns = ['quantity_traded_eth', 'avg_traded_price_eth', 'amount_traded_usd_eth', 'n_trades_eth',
-                 'open_eth_cc', 'open_eth_exchange',
-                 'quantity_traded_btc', 'avg_traded_price_btc', 'amount_traded_usd_btc', 'n_trades_btc',
-                 'open_btc_cc', 'open_btc_exchange',
-                 'wallet_amount_usd', 'transfers_usd','wallet_binance_balance',
-                 'trading_fees_usd_eth', 'funding_fees_usd_eth', 'slippage_eth_price_cc', 'slippage_eth_cash_cc','slippage_eth_price_bnc', 'slippage_eth_cash_bnc',
-                 'trading_fees_usd_btc', 'funding_fees_usd_btc', 'slippage_btc_price_cc', 'slippage_btc_cash_cc','slippage_btc_price_bnc', 'slippage_btc_cash_bnc' ]
+        x.index = td.date
+        x = x.rename_axis('timestamp')
+        x.columns = ['quantity_traded_eth', 'avg_traded_price_eth', 'amount_traded_usd_eth', 'n_trades_eth',
+                     'open_eth_cc', 'open_eth_exchange',
+                     'quantity_traded_btc', 'avg_traded_price_btc', 'amount_traded_usd_btc', 'n_trades_btc',
+                     'open_btc_cc', 'open_btc_exchange',
+                     'wallet_amount_usd', 'transfers_usd','wallet_binance_balance',
+                     'trading_fees_usd_eth', 'funding_fees_usd_eth', 'slippage_eth_price_cc', 'slippage_eth_cash_cc','slippage_eth_price_bnc', 'slippage_eth_cash_bnc',
+                     'trading_fees_usd_btc', 'funding_fees_usd_btc', 'slippage_btc_price_cc', 'slippage_btc_cash_cc','slippage_btc_price_bnc', 'slippage_btc_cash_bnc' ]
 
-    x = x.fillna(0).round(decimals=5)
+        x = x.fillna(0).round(decimals=5)
 
-    full_path = local_root_directory + report_pkl_file_name
-    x.to_pickle(full_path)
-    print(f'uploading to dropbox {full_path}')
-    dbx.upload(fullname=full_path, folder='', subfolder='', name=report_pkl_file_name, overwrite=True)
-    os.remove(full_path)
+        full_path = local_root_directory + report_pkl_file_name
+        x.to_pickle(full_path)
+        print(f'uploading to dropbox {full_path}')
+        dbx.upload(fullname=full_path, folder='', subfolder='', name=report_pkl_file_name, overwrite=True)
+        os.remove(full_path)
     return x
